Microsoft Dynamics NAV Anypoint&trade; Connector Demo - Page Operations CRUD
=====================================

Mule Studio demo for Microsoft Dynamics NAV connector.

Prerequisites
--------------

* Java 7
* Anypoint Studio 5.4.x or higher (It's advisable to use the latest one)
* Mule Runtime 3.7.x EE or higher
* DataWeave
* A published Page web service. For the demo, the **Countries/Regions** Page is used, published with name 'Countries' (NAV
web service ID 10). Please see (link:https://msdn.microsoft.com/en-us/library/dd355316(v=nav.80).aspx [Publishing a Page service] for more details about how to publish a Page service.
* A user with an access token configured for accessing web services.

Import the project
--------------

* Go to **File > Import**
* Select **Anypoint Studio Project from External Location** (under the parent folder "Anypoint Studio")

    ![Import Menu](images/nav-import-menu.png)

* Provide the root path to the demo project folder.
* Select Mule Runtime (3.7.x EE or higher).

    ![File Selection](images/nav-import-file.png)

* Click **Finish**.
* Set NAV credentials inside the file `src/main/app/mule-app.properties`. This may vary depending on the selected connection configuration. The current demo uses **OAuth 2.0 Access Token**:

    ```
    nav.accessToken=<ACCESS_TOKEN>
    ```

* Open the **Global Element Configuration**.

    ![Global Element](images/nav-connection-config.png)

* Click the **Test Connection** button to ensure there is connectivity with the sandbox. A successful message should pop-up.

    ![Test Connection](images/nav-connection-test.png)

* Open a browser and access the URL **http://localhost:8081**. You should see the demo application deployed:

    ![Demo Index](images/nav-demo-page.png)

About the flows
---------------

* **CreateCountryAndGetRecID**: Creates a new country entity with the given Name and Code and returns it's Record ID (Country/Region: Code)
![Create](images/CreateCountryAndGetRecID.png)
* **ReadCountry_ODataAndSOAPInSameFlow**: Sends an REST OData query and through a SOAP page web service gets more information about the given results.
![Read](images/ReadCountry_ODataAndSOAPInSameFlow.png)
* **UpdateCountry**: Updates a Country's Name and/or Code with the given Key and returns the result.
![Update](images/UpdateCountry.png)
* **DeleteCountry**: Deletes the Country related to the given Key

Run the Demo
---------------

### List Countries

* The default query fetches the Codes and Names from the Countries available from the Page web service in a descending order by their Code, fetching only 100 records. This can be changed if desired.
    ![List](images/nav-list-countries.png)
* Click the button List to send the query
* If the request is successful, a list like this will appear:
    ![Results](images/nav-countries-list.png)
    
Note: To perform a delete or update on any of the countries in the list, click on the desired country and the relevant data will be populated in the input fields of the aforementioned operations.
### Delete Country

* If you clicked a country from the list fetched by the List countries section, the **Name** and **Key** fields should already be populated. Click the delete button in order to perform the operation.
    ![Delete](images/nav-delete-country.png)
* Otherwise, provide the **Name**, **Code** and **Key** of the Country to be deleted and click the button to perform the operation.
* If successful, a popup will show saying that the deletion was successful.
    ![Popup](images/nav-deleted.png)
### Create Country

* Provide the **Name** and **Code** of the new Country
    ![Create](images/nav-create.png)
* Click the button **Create** and wait for the operation to be performed.
* If successful, the new Country's Record ID will be shown in the response field.
    ![Created](images/nav-created.png)
### Update Country

* Provide the **Name**, **Code** and **Key** of the Country to be updated. The **Name** or **Code** field can be left untouched if the user doesn't want to change it.
    ![Update](images/nav-update-country.png)
* If successful, a JSON with the updated information of the Country will be shown in the response field.
    ![Updated](images/nav-updated.png)
* This error message will appear if the Country was already updated, as the Key changes when that is done, or deleted.
    ![AlreadyUpdatedOrDeleted](images/nav-update-already-modified.png)